Learn R Programming

estar (version 1.0-1)

calc_dissim: Calculate dissimilarity

Description

Calculate dissimilarity

Usage

calc_dissim(df, comm_t, method, binary)

Arguments

df

dataframe with "temporal community data": species abundances of the baseline and disturbed communities over time.

comm_t

the name of the time variable in comm_b and comm_d.

method

a string identifying the dissimilarity index to be used to calculate dissimilarity. For more options, see ?vegdist. Defaults to "bray".

binary

a boolean stating whether presence/absence standardization should be performed before calculating the dissimilarity. For more options, see ?vegdist. Defaults to "bray".