Learn R Programming

estar (version 1.0-1)

comm_dist: Macroinvertebrate aquatic community data formatted for calculation of compositional stability metrics

Description

Data frame created with data-raw/estar_data.R. Data for a disturbed community: mean abundance calculated from the values for the experiments under treatment with 6 microg / L of insecticide.

Usage

comm_dist

Arguments

Format

A data frame with five variables:

Fields

time

sequential week number relative to the application of insecticide

herb

mean abundance of herbivores

detr_herb

mean abundance of detri-herbivores

carn

mean abundance of carnivores

omni

mean abundance of omnivores

detr

mean abundance of detrivores