Learn R Programming

estar (version 1.0-1)

summ_d2b: Summarize the values of the state variable in a disturbed system into a baseline

Description

Internal function, used in resistance(), recovery_rate() and recovery_extent() to create a baseline value out of the pre-disturbance values in the disturbed system.

Usage

summ_d2b(dts_df, b_tf, summ_mode, na_rm)

Value

A numeric, the baseline summary value.

Arguments

b_tf

a numerical vector, specifying the beginning and end of the pre-disturbance time period for the disturbed time-series that defines the baseline. Obligatory if (b = "d"), see 'Details'.

na_rm

a logical determining whether NAs should be taken out prior to the estimation of the stability metric. Defaults to TRUE.