Calculate dissimilarity
calc_dissim(df, comm_t, method, binary)dataframe with "temporal community data": species abundances of the baseline and disturbed communities over time.
the name of the time variable in comm_b and comm_d.
a string identifying the dissimilarity index to be used to
calculate dissimilarity. For more options, see ?vegdist.
Defaults to "bray".
a boolean stating whether presence/absence standardization
should be performed before calculating the dissimilarity. For more options,
see ?vegdist. Defaults to "bray".