Internal function, used in resistance(), recovery_rate() and
recovery_extent() to create a baseline value out of the
pre-disturbance values in the disturbed system.
summ_d2b(dts_df, b_tf, summ_mode, na_rm)A numeric, the baseline summary value.
a numerical vector, specifying the beginning and end of the
pre-disturbance time period for the disturbed time-series that defines
the baseline. Obligatory if (b = "d"), see 'Details'.
a logical determining whether NAs should be taken out prior to the estimation of the stability metric. Defaults to TRUE.